﻿Shader "Custom/distortion" {

	Properties {
	
		_MainTex( "Frame buffer", 2D ) = "" { }
	}
	
	SubShader {

		Pass {
		
			ZTest Always
			ZWrite Off

			CGPROGRAM

			#pragma vertex vertexMain
			#pragma fragment fragmentMain

			sampler2D _MainTex;
			
			struct vertexInput {

				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
			};
			
			struct fragmentInput {

				float4 vertex : POSITION;
				float4 texcoord : TEXCOORD0;
			};

			fragmentInput vertexMain( vertexInput input ) {

				fragmentInput output;

				output.vertex = mul( UNITY_MATRIX_MVP, input.vertex );
				output.texcoord.xy = input.texcoord.xy;

				return output;
			}
			
			float4 fragmentMain( fragmentInput input ) : COLOR {

				float3 color = float3( 0.0f, 0.0f, 0.0f );

				if ( input.texcoord.y > 0.5f ) {
					color = tex2D( _MainTex, input.texcoord.xy ).rgb;
				} else {

					float pi = 3.14159;
					float linearPosition = input.texcoord.y * 2.0f;

					float yFactor = sin( ( input.texcoord.y + _Time.x ) * 6.0f * 2.0f * pi );
					color = tex2D( _MainTex, float2( input.texcoord.x + yFactor * ( ( 1.0f - linearPosition ) * 0.015f ), input.texcoord.y ) ).rgb;

					yFactor = sin( ( input.texcoord.y + _Time.x * 1.25f ) * 9.0f * 2.0f * pi );
					color = color * 0.9f + tex2D( _MainTex, float2( input.texcoord.x + yFactor * ( ( 1.0f - linearPosition ) * 0.05f ), input.texcoord.y ) ).rgb * 0.1f;

					yFactor = sin( ( input.texcoord.y + _Time.x * 1.5f ) * 15.0f * 2.0f * pi );
					color = color * 0.9f + tex2D( _MainTex, float2( input.texcoord.x + yFactor * ( ( 1.0f - linearPosition ) * 0.1f ), input.texcoord.y ) ).rgb * 0.1f;
				}

				return float4( color, 1.0f );			
			}
			
			ENDCG
		}
	} 
	
	FallBack Off
}
